@@ -257,8 +257,16 @@ prep.step_umap <- function(x, training, info = NULL, ...) {
   check_number_decimal(x$min_dist, arg = "min_dist")
   check_number_decimal(x$learn_rate, min = 0, arg = "learn_rate")
   check_number_whole(x$epochs, min = 0, allow_null = TRUE, arg = "epochs")
-  rlang::arg_match0(x$initial, initial_umap_values, arg_nm = "initial")
-  check_number_decimal(x$target_weight, min = 0, max = 1, arg = "target_weight")
+  if (!is.null(x$initial)) {
+    rlang::arg_match0(x$initial, initial_umap_values, arg_nm = "initial")
+  }
+  check_number_decimal(
+    x$target_weight,
+    min = 0,
+    max = 1,
+    allow_null = TRUE,
+    arg = "target_weight"
+  )
 
   if (length(col_names) > 0) {
     if (length(x$outcome) > 0) {
@@ -267,7 +275,7 @@ prep.step_umap <- function(x, training, info = NULL, ...) {
       y_name <- NULL
     }
     x$neighbors <- min(nrow(training) - 1, x$neighbors)
-    x$num_comp <- min(length(col_names) - 1, x$num_comp)
+    x$num_comp <- min(length(col_names), x$num_comp)
 
     if (is.null(x$initial)) {
       x$initial <- "spectral"
